#!/bin/bash
#
# Base Script Author: Pedro Pinto (pnboy~AT~pinguix.com)
#
# author           : Pedro Sousa (pedrocgsousa~AT~gmail.com)
# latest update    : 04-07-2007
# source location  : http://www.csse.uwa.edu.au/cnet/cnet-2.0.10.tgz
# url              : http://www.csse.uwa.edu.au/cnet/


NAME=cnet
VERSION=2.0.10
ARCH=${ARCH:-i486}
CPU=${CPU:-i686}
BUILD=${BUILD:-48.1}
TMP=${TMP:-/tmp}
PKG=$TMP/package-$NAME
CWD=`pwd`
EXTENSION=tgz

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
#numjobs='-j2'

rm -rf $PKG
mkdir -p $PKG

cd $TMP
rm -rf $NAME-$VERSION
  if [ -f $NAME-$VERSION.$EXTENSION ]; then
          echo "Source file already here, no need to re-download";
  elif [ -f $CWD/$NAME-$VERSION.$EXTENSION ]; then
          echo -n "Relocating source file to $TMP..."
          cp $CWD/$NAME-$VERSION.$EXTENSION $TMP/
	  echo "done"
  else
	  wget -c http://www.csse.uwa.edu.au/cnet/$NAME-$VERSION.$EXTENSION
  fi
  tar xf $NAME-$VERSION.$EXTENSION

cd $NAME-$VERSION

# Configure:
mkdir -p $PKG/usr/man/man1
mkdir -p $PKG/usr/bin
sed -i -e 's|= /usr/local|= $(DESTDIR)/usr|g' Makefile
sed -i -e 's|= $(PREFIX)/cnetlib|= $(PREFIX)/share/cnetlib|g' Makefile
sed -i -e 's|= /home/httpd/html/cnet|= $(DESTDIR)/var/www/htdocs/cnet|g' Makefile
sed -i -e 's|= -O|=-O2 -march=i486 -mtune=i686|g' src/Makefile.linux

# Build and install:
make $numjobs || exit 1
make install DESTDIR=$PKG || exit 1
make web DESTDIR=$PKG || exit 1

# Strip binaries:
( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# etc/profile.d
mkdir -p $PKG/etc/profile.d
cat << EOF > $PKG/etc/profile.d/cnet.sh
#!/bin/sh
# Environment variables for the Cnet package.
#

export CNETPATH=/usr/share/cnetlib
EOF
cat << EOF > $PKG/etc/profile.d/cnet.csh
#!/bin/csh
# Environment path variables for the Cnet package:
setenv CNETPATH /usr/share/cnetlib
EOF
chmod 755 $PKG/etc/profile.d/cnet.*

# Compress the man page(s)
if [ -d $PKG/usr/man ]; then
	find $PKG/usr/man -type f -name "*.?" -exec gzip -9f {} \;
fi
if [ -d $PKG/usr/info ]; then
	find $PKG/usr/info -type f -name "*.info*" -exec gzip -9f {} \;
fi

# Add a documentation directory:
mkdir -p $PKG/usr/doc/$NAME-$VERSION

# The Makefile evidently contains the package's license...
DOCS="ANNOUNCE src/COPYRIGHT src/GPL src/HIDENAMES"
cd $TMP/$NAME-$VERSION
cp -a \
  $DOCS \
  $PKG/usr/doc/$NAME-$VERSION

# Add a examples directory:
mkdir -p $PKG/usr/share/$NAME

# Copy examples directory
cd $TMP/$NAME-$VERSION
cp -a \
  EXAMPLES \
  $PKG/usr/share/$NAME
chmod 755 $PKG/usr/share/$NAME/EXAMPLES

# 
# as per package rules: add the build-file itself
#
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

mkdir -p $PKG/install

#    |-----handy-ruler------------------------------------------------------|
echo "$NAME: $NAME - (network simulator)
$NAME:
$NAME: The cnet network simulator, enables experimentation with various
$NAME: data-link layer, network layer,routing and transport layer networking
$NAME: protocols in networks consisting of any combination of point-to-point
$NAME: links and IEEE 802.3 Ethernet segments. cnet has been specifically
$NAME: developed for, and is used in, undergraduate computer networking
$NAME: courses taken by thousands of students worldwide since 1991.
$NAME: 
$NAME: 
$NAME:" > $PKG/install/slack-desc

#
# real packaging work:
#
# Make sure ownerships and permissions are sane:
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n ../$NAME-$VERSION-$ARCH-$BUILD.tgz

#
# computes the md5sum signature for the package
#
cd $TMP
echo "Compute MD5..."
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5
echo "Finding dependencies..."
requiredbuilder -z $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.dep

echo "Moving Package to: "$CWD
mv $NAME-$VERSION-$ARCH-$BUILD.* $CWD

echo "Removing tmp files"
rm -rf $PKG
rm -rf $TMP/$NAME-$VERSION

echo "Build finished!"
